@@ -15,7 +15,7 @@ BASE_RESULTS_PATH = os.environ.get("BASE_RESULTS_PATH", "results")
 
 
 def mkdir(endpoint, spec_path=""):
-    folder = os.path.join(BASE_RESULTS_PATH, endpoint.profile_func.__name__, spec_path)
+    folder = os.path.join(BASE_RESULTS_PATH, endpoint.series_func.__name__, spec_path)
     if not os.path.exists(folder):
         os.makedirs(folder)
     return folder
@@ -23,10 +23,14 @@ def mkdir(endpoint, spec_path=""):
 
 def create_shapley_schema(endpoint):
     """Create shapley schema for endpoint"""
-    x, y = endpoint.get_input_and_output_for_profiling()
-    explainer = ShapExplainer(func=endpoint.profile_func, X=x)
+    x, y = endpoint.get_input_and_output_for_profiling(full_x=True)
+    explainer = ShapExplainer(
+        func=endpoint.series_func, X=x, profile_columns=endpoint.profile_columns
+    )
     folder = mkdir(endpoint=endpoint)
-    input_descriptions = [create_description(x[col]) for col in x.columns]
+    input_descriptions = [
+        create_description(x[col]) for col in endpoint.profile_columns
+    ]
     logging.info("Shapley - Creating schema")
     fname = "schema.json"
     fpath = os.path.join(folder, fname)
@@ -38,12 +42,14 @@ def create_shapley_schema(endpoint):
 def create_explainer_schema(endpoint, explainer, input_descriptions):
     """Create schema for explainer input"""
     # create an example
-    x, y = endpoint.get_input_and_output_for_profiling()
+    x, y = endpoint.get_input_and_output_for_profiling(full_x=False)
     x = x.sample(n=1)
-    pred = endpoint.profile_func(x)
+    # Use explainer instead of endpoint because func is partialed out, only takes in profile_columns
+    pred = explainer.func(x)
     baseline, explanation = explainer.explain(x)
+
     example = {
-        "inputs": endpoint.input_schema.pydantic.schema()["example"],
+        "inputs": endpoint.explain_input_schema.pydantic.schema()["example"],
         "explanations": df_to_dict(explanation),
         "prediction": list(pred),
         "baseline": list(baseline),
@@ -55,8 +61,8 @@ def create_explainer_schema(endpoint, explainer, input_descriptions):
 
 def create_accuracy(endpoint):
     """Create accuracy profile for endpoint"""
-    x, y = endpoint.get_input_and_output_for_profiling()
-    func = endpoint.profile_func
+    x, y = endpoint.get_input_and_output_for_profiling(full_x=True)
+    func = endpoint.series_func
     kind = endpoint.KIND.value
     folder = mkdir(endpoint=endpoint, spec_path="accuracy")
 
@@ -76,18 +82,18 @@ def create_accuracy(endpoint):
     logging.info("Accuracy - Finding largest errors")
     fname = "errors.json"
     fpath = os.path.join(folder, fname)
-    errors_table = largest_errors(func, x, y)
+    errors_table = largest_errors(func, x, y, endpoint.profile_columns)
     with open(fpath, "w") as f:
         f.write(errors_table)
 
 
 def create_dependence(endpoint):
     """Create partial dependence graphs for all variables"""
-    x, y = endpoint.get_input_and_output_for_profiling(reset_index=True)
-    func = endpoint.profile_func
+    x, y = endpoint.get_input_and_output_for_profiling(full_x=True, reset_index=True)
+    func = endpoint.series_func
     folder = mkdir(endpoint=endpoint, spec_path="anatomy/partialdep")
 
-    for var in x.columns:
+    for var in endpoint.profile_columns:
         logging.info(f"Explanations - Creating partial dependence for {var}")
         fname = var + ".json"
         fpath = os.path.join(folder, fname)
@@ -100,11 +106,11 @@ def create_dependence(endpoint):
 
 def create_expectations(endpoint):
     """Create conditional expectations graphs for all variables"""
-    x, y = endpoint.get_input_and_output_for_profiling(reset_index=True)
-    func = endpoint.profile_func
+    x, y = endpoint.get_input_and_output_for_profiling(full_x=True, reset_index=True)
+    func = endpoint.series_func
     folder = mkdir(endpoint=endpoint, spec_path="anatomy/condexp")
 
-    for var in x.columns:
+    for var in endpoint.profile_columns:
         logging.info(f"Explanations - Creating conditional expectations for {var}")
         fname = var + ".json"
         fpath = os.path.join(folder, fname)
@@ -121,14 +127,14 @@ def create_expectations(endpoint):
 
 def create_importance(endpoint):
     """Create variable importance graphs"""
-    x, y = endpoint.get_input_and_output_for_profiling()
-    func = endpoint.profile_func
+    x, y = endpoint.get_input_and_output_for_profiling(full_x=True)
+    func = endpoint.series_func
 
     logging.info("Explanations - Calculating variable importance")
     if endpoint.KIND.value == "regression":
-        chart, varlist = varimp(func, x, y, metric="Rmse")
+        chart, varlist = varimp(func, x, y, endpoint.profile_columns, metric="Rmse")
     elif endpoint.KIND.value == "binary":
-        chart, varlist = varimp(func, x, y, metric="AUC")
+        chart, varlist = varimp(func, x, y, endpoint.profile_columns, metric="AUC")
     else:
         raise NotImplementedError("Unknown endpoint kind:" + endpoint.KIND.value)
 
@@ -145,13 +151,17 @@ def create_importance(endpoint):
         json.dump(varlist, f)
 
 
-def create_summary(endpoint):
-    endpoint_name = endpoint.profile_func.__name__
+def create_summary(endpoint, explain_only=False):
+    endpoint_name = endpoint.series_func.__name__
     logging.info(f"Summary - creating endpoint summary for endpoint: {endpoint_name}")
+    if explain_only:
+        endpoint_input_names = endpoint.explain_input_names
+    else:
+        endpoint_input_names = endpoint.input_names
     as_json = {
         "name": endpoint_name,
         "kind": endpoint.KIND.value,
-        "inputs": endpoint.input_names,
+        "inputs": endpoint_input_names,
         "output": endpoint.output_names,
     }
     # Save to disk
